#
# spec file for package perl-Date-Manip
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Date-Manip
Version:        6.42
Release:        3.5
%define cpan_name Date-Manip
Summary:        Date manipulation routines
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Date-Manip/
Source:         http://www.cpan.org/authors/id/S/SB/SBECK/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Test::Inter)
#BuildRequires: perl(Date::Manip)
#BuildRequires: perl(Date::Manip::Base)
#BuildRequires: perl(Date::Manip::Date)
#BuildRequires: perl(Date::Manip::Delta)
#BuildRequires: perl(Date::Manip::DM5abbrevs)
#BuildRequires: perl(Date::Manip::Lang::index)
#BuildRequires: perl(Date::Manip::Obj)
#BuildRequires: perl(Date::Manip::Recur)
#BuildRequires: perl(Date::Manip::TZ)
#BuildRequires: perl(Date::Manip::TZ_Base)
#BuildRequires: perl(Date::Manip::Zones)
#BuildRequires: perl(Date::Parse)
#BuildRequires: perl(DateTime::Format::DateParse)
#BuildRequires: perl(Win32::TieRegistry)
Requires:       perl(Test::Inter)
%{perl_requires}

%description
Date::Manip is a series of modules designed to make any common date/time
operation easy to do. Operations such as comparing two times, determining a
date a given amount of time from another, or parsing international times
are all easily done. It deals with time as it is used in the Gregorian
calendar (the one currently in use) with full support for time changes due
to daylight saving time.

From the very beginning, the main focus of Date::Manip has been to be able
to do ANY desired date/time operation easily. Many other modules exist
which may do a subset of these operations quicker or more efficiently, but
no other module can do all of the operations available in Date::Manip.

Since many other date/time modules exist, some of which may do the specific
operation(s) you need faster, be sure to read the section SHOULD I USE
DATE::MANIP in the Date::Manip::Misc document before deciding which of the
Date and Time modules from CPAN is for you. However, if you want one module
to do it all, Date::Manip is the one to use.

Date::Manip has functionality to work with several fundamental types of
data.

* *dates*

  The word date is used extensively here and is somewhat misleading. In
  Date::Manip, a date consists of three pieces of information: a calendar
  date, a time of day, and time zone information. Calendar dates and times
  are fully handled. Time zones are handled as well, but depending on how
  you use Date::Manip, there may be some limitations as discussed below.

* *delta*

  A delta is an amount of time (i.e. the amount of time between two
  different dates). A delta refers only to an amount of time. It includes
  no information about a starting or ending date/time. Most people will
  think of a delta as an amount of time, but the term 'time' is already
  used so much in this module that I didn't want to use it here in order to
  avoid confusion.

* *recurrence*

  A recurring event is something which occurs on a regular recurring basis.

* *holidays* and *events*

  Holidays and events are basically named dates or recurrences.

Among other things, Date::Manip allow you to:

* ***

  Enter a date in practically any format you choose.

* ***

  Compare two dates, entered in widely different formats to determine which
  is earlier.

* ***

  Extract any information you want from a date using a format string
  similar to the Unix date command.

* ***

  Determine the amount of time between two dates, or add an amount of time
  to a date to get a second date.

* ***

  Work with dates with dates using international formats (foreign month
  names, 12/10/95 referring to October rather than December, etc.).

* ***

  To find a list of dates where a recurring event happens.

Each of these tasks is trivial (one or two lines at most) with this
package.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc examples HISTORY LICENSE README README.first

%changelog
* Mon Dec  9 2013 coolo@suse.com
- updated to 6.42
  * Added ParseDateFormat function
  Added the ParseDateFormat function to the DM6 functional interface
  in response to RT 89286.
  * Added Common Log format
  Added the date format used in apache logs: 11/Oct/2000:13:55:36 -0700
  RT 89286.
  * Time zone fixes
  Newest zoneinfo data (tzdata 2013h)
  * Bug fixes
  Fixed a bug where dates of the form of a delta with a timezone attached
  (i.e. "1 day ago at midnight UTC") failed.  RT 89256
  Fixed a bug where events handling gave a warning if there were no events
  that applied.  RT 90344
* Fri Oct  4 2013 coolo@suse.com
- updated to 6.41
  Removed a .swp file accidentally left in the package.  RT 85845
  Fixed a bug in parse_format where times between 00:00:00 and 01:00:00 weren't
  parsed correctly.  Ole Nomann Thomsen
  Fixed generated META.* files to not require Module::Build 0.39.  RT 86137
  Fixed a bug where parse_format did not work with a '%%s' format.  RT 87498
  Fixed a bug where find_encoding wasn't imported from the Encode module.  RT 87665
  Fixed a bug where recurrences with no interval did not work if a start and
  end date were specified, and no dates fell in that range.  Jan Pradac
  * Time zone fixes
  Newest zoneinfo data (tzdata 2013d)
* Tue Jun  4 2013 coolo@suse.com
- updated to 6.40
  documentation is no longer generated for Date::Manip::TZ::* and
  Date::Manip::Offset::* modules.
  Newest zoneinfo data (tzdata 2013c)
  Added the $mode argument to ParseDateDelta
  The ParseDateDelta function (in functional interface) did not allow you
  to force a parsed delta to semi or approx where appropriate.  This
  was added.  Based on RT 82991).
  Added get_config method
  The get_config method was added to all classes.  Suggested by Philippe Poilbarbe.
  Language fixes
  Fixed a German language problem.  Gosta Oelstrom
  Documentation fixes
  Documented workaround for dmake problem in strawberry perl.  Discussed on
  perlmonks and RT 79837.
  Clarified the Examples page.  Winston Heng
* Tue Mar  6 2012 coolo@suse.com
- updated to 6.31
  * Added extended formats to printf method.
  * Can now parse formats where the time and zone are not adjacent
  * Added PeriodTimeSep config variable.
  * Holidays can be used as date strings
  * Added new recur modifiers
  * Tons of new test cases and bug fixes
* Fri Jan 13 2012 vcizek@suse.com
- update to 6.30
  * Removed some deprecated config variables
  * Reworked deltas
  * Modified Delta_Format
  * Time zone fixes
  * Better handling of undef in DM6
  * Bug fixes
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Thu Sep  1 2011 pascal.bleser@opensuse.org
- update to 6.25:
  * relaxed one constraint in ISO 8601 dates: a time separated by whitespace
    from the date can use a single digit hour
  * set official removal dates for old config variables; config variables will
    be removed 2 years after they are deprecated (except for the TZ variable
    which, due to it's wide use, will be kept for 4 years)
  * time zone fixes: newest zoneinfo data (tzdata 2011i)
* Tue Jun 14 2011 vcizek@novell.com
- update to 6.24
  New features
    Spaces are ignored in the SetDate/ForceDate config values.  Zsban Ambrus
  Bug fixes
    Fixed a bug where 'in one week' wasn't correctly parsed.  E. M. Shtern
    Fixed a bug where options passed in to the 'new' as a listref weren't handled
    properly.  Zsban Ambrus
  Time zone fixes
    Newest zoneinfo data (tzdata 2011g)
* Mon Apr 18 2011 vcizek@novell.com
- update to 6.23
    Bug fixes
    Fixed a bug where GlobalCnf wasn't working. Peter Edwards
    Improved error messages in a few cases.
    Fixed a bug where one invalid date/timezone check was ignored. Morten
    Bjornsvik
    Fixed a bug where '$base2 = new Date::Manip::Base $base1' wasn't
    working. RT 67143
    Fixed a bug where passing dates in to the Recur->dates method failed.
    RT 67144
    Fixed a bug where the mode wasn't being preserved correctly for a
    delta. RT 67150
    Fixed a bug in recurrences where a base date outside of a date range
    with a very uncommon recurrence format would not work correctly.
    Fixed a problem where the '%%s' printf option didn't work in GMT.
    Time zone fixes
    Newest zoneinfo data (tzdata 2011f)
* Wed Mar  9 2011 vcizek@novell.com
- update to 6.22
  Time zone fixes:
  Newest zoneinfo data (tzdata 2011b).
  Fixed a bug where the gmtoff method of getting the local timezone was broken.
  Fixed the 'env' method of determining the local time zone to allow the
  value to be an offset of seconds since UTC.  This allows the VMS
  SYS$TIMEZONE_DIFFERENTIAL variable to work correctly.  Martin Zinser.
  Removed the SYS$TIMEZONE_RULE method from VMS since the value stored there
  is not the name of a timezone (it's a rule in a non-standard format).  Based
  on discussion with Martin Zinser.
  Language fixes:
  The module will now die if a language module cannot be loaded (most
  likely due to a YAML::Syck issue).  Based on discussion with Martin Zinser.
  Documentation fixes:
  Added a sample config file document.  Based on discussion with Rich Duzenbury.
* Wed Jan 19 2011 vcizek@novell.com
- update to 6.21
  New features
  - Deltas may now contain spelled out numbers, so 'in 2 weeks' and 'in two weeks'
    will both work.  Daniel Shahaf
  Bug fixes
  - Fixed a bug where week_of_year didn't work in some cases.  Chris Eveland.
  - Fixed a minor potential bug.  Geraint Edwards.
  Time zone fixes
  - Updated windows time zone aliases.  Daniel Harding
  Language fixes
  - Added Norwegian.  Glenn Sogn
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Oct 21 2010 anicka@suse.cz
- update to 6.14
  * Date::Manip 5.xx and 6.xx are both installed automatically,
  and the correct one will be chosen.
  * Fixed a bug where recurrence handling was broken.  RT 62128
  * documentation was cleaned up to be easier to read, and better
  organized.
* Mon Oct 18 2010 anicka@suse.cz
- update to 6.13
  * Added the input methods to Date::Manip::Date and
  Date::Manip::Delta.
  * The 'date +%%z' command will also be used to determine
  the timezone.
  * bugfixes
* Thu Sep 30 2010 anicka@suse.cz
- update to 6.12
  * With better support for international character sets, the old
  IntCharSet config variable is deprecated.
  * Added the Encoding config variable.
  * Now supports parsing the EXIF date format.
  * bugfixes
* Wed Jul 21 2010 coolo@novell.com
- keep the obsoletes/provides of 11.1 renames
* Tue Jul 20 2010 chris@computersalat.de
- update to 6.11
  - Fixed a problem in Build.PL that had an incorrect module requirement.
- Version 6.10  2010-04-29
  Fixed a bug where Date_ConvTZ not working correctly with timezones specified
    by offset.  Chris Butler
  Fixed a documentation bug in Date::Manip::TZ where "stdonly" was listed as the
    default value for $dstflag, but in actuality, "std" is the default.
  Changed Date::Manip::TZ::zone so "dst" is sometimes the default $dstflag.
    Based on the bug report by Chris Butler.
  OpenUNIX puts a colon at the start of some timezones. It's removed.  Jean Hassler
  Fixed a bug where business mode calculations involving minutes was not handled
    correctly.  Damien Moore
  * ** Combined 5.xx and 6.xx releases into one distribution so cpan/cpanp will
    work correctly.
  Newest zoneinfo data (tzdata 2010i)
  Fixed a bug where business mode calculations failed in some cases.  RT 56638
  Converted tests to Test::Inter
- recreated by cpanspec 1.78
- noarch pkg
* Fri Feb 26 2010 anicka@suse.cz
- update to 6.07
  * Added dm_zdump example script.
  * Minor bug where %%Z printf format didn't always work.
  * Improved TZ::periods functionality
  * Fixed bug in Date_ConvTZ where empty values weren't defaulting
  to local timezone.
  * Fixed a couple of problems in the generated timezones for some
  odd cases (America/Resolute and Asia/Tehran).
  * Added support for 5pm back in (it was omitted accidentally).
  * Fixed a minor warning.
  * Some additional speedups.
  * Newest zoneinfo data.
  * Fixed bug in Date_TimeZone where it wasn't returning
  the timezone.
* Sat Dec 12 2009 chris@computersalat.de
- update to 6.05
  * Significant speedups. Thanks to Moritz Lenz and BrowserUK on perlmonks for
    suggestions (and a number of other people on perlmonks for suggestions
    that I did not end up using, but which provided a great discussion).
  * Reduced the precision of 1 test to avoid a rounding difference when using
    a perl compiled with uselongdouble.  Andreas Koenig
  * Fixed a bug in parse_date where the current time was getting used instead
    of the documented 00:00:00
  * Bug fix where DateCalc didn't work with $mode in some cases.
  * Fixed Makefile.PL/Build.PL to hanle Win32::TieRegistry requirement.
  * Changed %%z printf behavior back to 5.xx and added %%N format. Gilles Lamiral
  * Fixed bug where non-English Windows versions didn't get the timezone. Thanks
    to Rene Schickbauer for testing.
- cleanup spec
  * added cpan_name
  * sort tags
  * fix build-/deps
  * update desc
  * move changelog to .changes
- added perl-macros
  * perl_gen_filelist
* Wed Jul 23 2008 anicka@suse.cz
- update to 5.54
  * Final changes to meet requirements on http://cpants.perl.org/
- rename from perl-DateManip to perl-Date-Manip according to cpan
* Wed May  7 2008 lrupp@suse.de
- update to 5.50:
  * Corrected typo in %%G and %%L format descriptions
  * Added "ereyesterday"
  * Added new timezones
  * Added Build.PL and several other things to meet requirements on
    http://cpants.perl.org/
- remove INSTALL, added LICENSE and README.FIRST to doc
- build parallel
* Mon Mar 10 2008 anicka@suse.cz
- update to 5.48
  * Language fix for Danish.
  * Language fix for German.
  * New timezones.
  * Minor documentation improvement.
  * Revised some of the docs about Y2K (given that it's in the past)
  and the 2007 US daylight saving time rule changes.
  * bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 anicka@suse.cz
- update to 5.44
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 rommel@suse.de
- update to version 5.42a
- using perl_vendorlib and perl_vendorarch instead of
  perl_archlib and perl_sitearch
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Jun 22 2001 grimmer@suse.de
- Update to version 5.40
- use more perl macros in spec file
* Tue Nov  7 2000 grimmer@suse.de
- added .packlist to file list and removed BuildRoot path with sed
* Tue Nov  7 2000 grimmer@suse.de
- initial version (5.39)
